Paths
=====
.. autoclass:: cxroots.Paths.ComplexPath
	:members: trap_values, plot, show, integrate
	
Line
----
.. autoclass:: cxroots.Paths.ComplexLine
	:members: __call__, distance

Circular Arc
------------
.. autoclass:: cxroots.Paths.ComplexArc
	:members: __call__, distance
